==> org-lsst-ccs-subsystem-fcs-main-4.0.12-tests.jar: org/lsst/ccs/subsystems/fcs/scripts/autochangerProtoTest.py <==
###############################################################
#Script to test the real hardware of autochanger trucks and clamps on Scale 1 prototype
#
###############################################################

from org.lsst.ccs.scripting import CCS
from java.lang import Exception
from java.lang import RuntimeException
from org.lsst.ccs.command import *
from time import sleep


CCS.setThrowExceptions(True)

autochangerSubs = CCS.attachSubsystem("autochanger-standalone")

print "Connected to autochanger-standalone=> ", autochangerSubs 

ccsVersion= autochangerSubs.synchCommandLine(5,"getCCSVersions")
print "TESTS of autochanger trucks motion with CCS version number"
print ccsVersion.getResult()

#print "Date=", date

tcpProxy = CCS.attachSubsystem("autochanger-standalone/tcpProxy")

result = tcpProxy.synchCommandLine(5, "isHardwareReady")

print "isHardwareReady =", result.getResult()

trucks = CCS.attachSubsystem("autochanger-standalone/trucks")
##################################INITIALIZATION
#standbyPosition = 992000;
#handoffPosition = 70000;
#onlinePosition = 4700;

standbyPosition = int((trucks.synchCommandLine(5, "getStandbyPosition")).getResult())
print "STANDBY position=", standbyPosition

handoffPosition = int((trucks.synchCommandLine(5, "getHandoffPosition")).getResult())
print "HANDOFF position = ", handoffPosition

onlinePosition = int((trucks.synchCommandLine(5, "getOnlinePosition")).getResult())
print "ONLINE position =", onlinePosition

waitTime = int(1)

######################################################################
# check that initial conditions are OK
######################################################################

#Read of the linearRailSlaveController mode
slaveCtl = CCS.attachSubsystem("autochanger-standalone/linearRailSlaveController")
slaveMode = slaveCtl.synchCommandLine(5, "readMode")
print "Slave Controller Mode =", slaveMode.getResult()

#Read of the linearRailMasterController mode
masterCtl = CCS.attachSubsystem("autochanger-standalone/linearRailMasterController")
masterMode = masterCtl.synchCommandLine(5, "readMode")
print "Master Controller Mode =", masterMode.getResult()

if str(masterMode.getResult()) != 'PROFILE_POSITION' :
   #  raise Exception("ERROR on master Controller mode")
   print "ERROR on master Controller mode - have to change it."
   result = masterCtl.synchCommandLine(5, "changeMode PROFILE_POSITION")
else:
   print "master Controller is in mode", masterMode.getResult()

if str(slaveMode.getResult()) != 'MASTER_ENCODER' :
   #  raise Exception("ERROR on slave Controller mode")
   print "ERROR on slave Controller mode - have to change it."
   result = slaveCtl.synchCommandLine(5,"changeMode MASTER_ENCODER")
else:
   print "slave Controller is in mode", slaveMode.getResult()


######################################################################
# Move Trucks to STANDBY position if trucks are not already at STAND
######################################################################

position = int((masterCtl.synchCommandLine(5, "readPosition")).getResult())
print "INITIAL POSITION Position =", position
if position < standbyPosition - 100:
   print "Going to INITIAL position STANDBY"
   resultMvt=trucks.synchCommandLine(10000,"goToStandby")
   print "resultMvt=", str(resultMvt)
   position = int((masterCtl.synchCommandLine(5, "readPosition")).getResult())
   print "Position=", position
   sleep(waitTime)
   print "END OF GOING TO INITIAL POSITION"

#####################################################################
# loop to move the trucks from STANDBY to ONLINE
#####################################################################

for i in range(5):
   print "ITERATION number", i
   print "Going to ONLINE"
   resultMvt = trucks.synchCommandLine(10000, "goToOnline")
  #print "resultMvt = ", str(resultMvt)
   position = int((masterCtl.synchCommandLine(5, "readPosition")).getResult())
   print "Position =", position
   print "Sleeping", waitTime, "s....."
   sleep(waitTime)
   print "Going to STANDBY"
   resultMvt = trucks.synchCommandLine(10000, "goToStandby")
  #print "resultMvt=", str(resultMvt)
   position = int((masterCtl.synchCommandLine(5, "readPosition")).getResult())
   print "Position =", position
   print "Sleeping", waitTime, "s....."
   sleep(waitTime)
   print "end ITERATION number", i

print "END LOOP"

==> org-lsst-ccs-subsystem-fcs-main-8.3.0-tests.jar: org/lsst/ccs/subsystems/fcs/scripts/autochangerProtoTest.py <==
###############################################################
#Script to test the real hardware of autochanger trucks and clamps on Scale 1 prototype
#
###############################################################

from org.lsst.ccs.scripting import CCS
from java.lang import Exception
from java.lang import RuntimeException
from org.lsst.ccs.command import *
from time import sleep
import java.time

timeoutFiveMillis = java.time.Duration.ofMillis(5)
timeoutTenSec = java.time.Duration.ofSeconds(10)

CCS.setThrowExceptions(True)

autochangerSubs = CCS.attachSubsystem("autochanger-standalone")

print "Connected to autochanger-standalone=> ", autochangerSubs 

ccsVersion= autochangerSubs.sendSynchCommand(timeoutFiveMillis,"getCCSVersions")
print "TESTS of autochanger trucks motion with CCS version number"
print ccsVersion.getResult()

#print "Date=", date

tcpProxy = CCS.attachSubsystem("autochanger-standalone/tcpProxy")

result = tcpProxy.sendSynchCommand(timeoutFiveMillis, "isHardwareReady")

print "isHardwareReady =", result.getResult()

trucks = CCS.attachSubsystem("autochanger-standalone/trucks")
##################################INITIALIZATION
#standbyPosition = 992000;
#handoffPosition = 70000;
#onlinePosition = 4700;

standbyPosition = int((trucks.sendSynchCommand(timeoutFiveMillis, "getStandbyPosition")))
print "STANDBY position=", standbyPosition

handoffPosition = int((trucks.sendSynchCommand(timeoutFiveMillis, "getHandoffPosition")))
print "HANDOFF position = ", handoffPosition

onlinePosition = int((trucks.sendSynchCommand(timeoutFiveMillis, "getOnlinePosition")))
print "ONLINE position =", onlinePosition

waitTime = int(1)

######################################################################
# check that initial conditions are OK
######################################################################

#Read of the linearRailSlaveController mode
slaveCtl = CCS.attachSubsystem("autochanger-standalone/linearRailSlaveController")
slaveMode = slaveCtl.sendSynchCommand(timeoutFiveMillis, "readMode")
print "Slave Controller Mode =", slaveMode.getResult()

#Read of the linearRailMasterController mode
masterCtl = CCS.attachSubsystem("autochanger-standalone/linearRailMasterController")
masterMode = masterCtl.sendSynchCommand(timeoutFiveMillis, "readMode")
print "Master Controller Mode =", masterMode.getResult()

if str(masterMode.getResult()) != 'PROFILE_POSITION' :
   #  raise Exception("ERROR on master Controller mode")
   print "ERROR on master Controller mode - have to change it."
   result = masterCtl.sendSynchCommand(timeoutFiveMillis, "changeMode PROFILE_POSITION")
else:
   print "master Controller is in mode", masterMode.getResult()

if str(slaveMode.getResult()) != 'MASTER_ENCODER' :
   #  raise Exception("ERROR on slave Controller mode")
   print "ERROR on slave Controller mode - have to change it."
   result = slaveCtl.sendSynchCommand(timeoutFiveMillis,"changeMode MASTER_ENCODER")
else:
   print "slave Controller is in mode", slaveMode.getResult()


######################################################################
# Move Trucks to STANDBY position if trucks are not already at STAND
######################################################################

position = int((masterCtl.sendSynchCommand(timeoutFiveMillis, "readPosition")))
print "INITIAL POSITION Position =", position
if position < standbyPosition - 100:
   print "Going to INITIAL position STANDBY"
   resultMvt=trucks.sendSynchCommand(timeoutTenSec,"goToStandby")
   print "resultMvt=", str(resultMvt)
   position = int((masterCtl.sendSynchCommand(timeoutFiveMillis, "readPosition")))
   print "Position=", position
   sleep(waitTime)
   print "END OF GOING TO INITIAL POSITION"

#####################################################################
# loop to move the trucks from STANDBY to ONLINE
#####################################################################

for i in range(5):
   print "ITERATION number", i
   print "Going to ONLINE"
   resultMvt = trucks.sendSynchCommand(timeoutTenSec, "goToOnline")
  #print "resultMvt = ", str(resultMvt)
   position = int((masterCtl.sendSynchCommand(timeoutFiveMillis, "readPosition")))
   print "Position =", position
   print "Sleeping", waitTime, "s....."
   sleep(waitTime)
   print "Going to STANDBY"
   resultMvt = trucks.sendSynchCommand(timeoutTenSec, "goToStandby")
  #print "resultMvt=", str(resultMvt)
   position = int((masterCtl.sendSynchCommand(timeoutFiveMillis, "readPosition")))
   print "Position =", position
   print "Sleeping", waitTime, "s....."
   sleep(waitTime)
   print "end ITERATION number", i

print "END LOOP"
